// src/util/with-highlight-nodejs-page-router.ts
import { HIGHLIGHT_REQUEST_HEADER } from "@highlight-run/node";

// src/util/highlight-node.ts
import { H as NodeH } from "@highlight-run/node";
var H = {
  ...NodeH,
  init: (options) => {
    if (process.env.NEXT_RUNTIME === "nodejs") {
      if (!NodeH.isInitialized()) {
        NodeH.init(options);
      }
    } else {
      throw new Error(
        `Highlight not registered due to unexpected runtime: NEXT_RUNTIME=${process.env.NEXT_RUNTIME}`
      );
    }
  },
  initEdge: () => {
    throw new Error(
      "H.initEdge is not supported by the Node runtime. Try H.init instead."
    );
  },
  isInitialized: () => NodeH.isInitialized(),
  metrics: (metrics, opts) => {
    const h = global.__HIGHLIGHT__;
    if (h && !opts) {
      opts = h;
    }
    if (!opts?.secureSessionId) {
      return console.warn(
        "H.metrics session could not be inferred the handler context."
      );
    }
    for (const m of metrics) {
      NodeH.recordMetric(
        opts.secureSessionId,
        m.name,
        m.value,
        opts.requestId,
        m.tags
      );
    }
  },
  sendResponse: (_) => {
    throw new Error(
      "H.sendResponse is not implemented for the Node runtime."
    );
  }
};

// src/util/with-highlight-nodejs-page-router.ts
var Highlight = (options) => (origHandler) => {
  return async (req, res) => {
    if (!H.isInitialized()) {
      H.init(options);
    }
    const processHighlightHeaders2 = () => {
      if (req.headers && req.headers[HIGHLIGHT_REQUEST_HEADER]) {
        const [secureSessionId2, requestId2] = `${req.headers[HIGHLIGHT_REQUEST_HEADER]}`.split("/");
        if (secureSessionId2 && requestId2) {
          ;
          global.__HIGHLIGHT__ = { secureSessionId: secureSessionId2, requestId: requestId2 };
          return { secureSessionId: secureSessionId2, requestId: requestId2 };
        }
      }
      return { secureSessionId: void 0, requestId: void 0 };
    };
    const { secureSessionId, requestId } = processHighlightHeaders2();
    const start = /* @__PURE__ */ new Date();
    try {
      return await origHandler(req, res);
    } catch (e) {
      if (e instanceof Error) {
        await H.consumeAndFlush(e, secureSessionId, requestId);
      }
      res.statusCode = 500;
      res.statusMessage = "Internal Server Error";
      await H.stop();
      throw e;
    } finally {
      const delta = ((/* @__PURE__ */ new Date()).getTime() - start.getTime()) * 1e6;
      const { secureSessionId: secureSessionId2, requestId: requestId2 } = processHighlightHeaders2();
      if (secureSessionId2) {
        H.recordMetric(secureSessionId2, "latency", delta, requestId2);
        await H.flush();
      }
    }
  };
};

// src/util/with-highlight-nodejs-app-router.ts
import { HIGHLIGHT_REQUEST_HEADER as HIGHLIGHT_REQUEST_HEADER2, H as H2 } from "@highlight-run/node";
function Highlight2(options) {
  return (originalHandler) => async (request, context) => {
    try {
      H2.init(options);
      return await originalHandler(request, context);
    } catch (error) {
      const { secureSessionId, requestId } = processHighlightHeaders(request);
      if (error instanceof Error) {
        await H2.consumeAndFlush(error, secureSessionId, requestId);
      }
      await H2.stop();
      throw error;
    }
  };
}
function processHighlightHeaders(request) {
  const header = request.headers.get(HIGHLIGHT_REQUEST_HEADER2);
  if (header) {
    const [secureSessionId, requestId] = header.split("/");
    if (secureSessionId && requestId) {
      ;
      global.__HIGHLIGHT__ = {
        secureSessionId,
        requestId
      };
      return { secureSessionId, requestId };
    }
  }
  return { secureSessionId: void 0, requestId: void 0 };
}

// src/util/registerHighlight.ts
async function registerHighlight(nodeOptions) {
  if (process.env.NEXT_RUNTIME === "nodejs") {
    const { H: H4 } = await import("@highlight-run/node");
    H4.init(nodeOptions);
  } else {
    console.info(
      `Highlight not registered: NEXT_RUNTIME=${process.env.NEXT_RUNTIME}`
    );
  }
}

// src/util/highlightWebpackPlugin.ts
import { uploadSourcemaps } from "@highlight-run/sourcemap-uploader/dist/lib";
var HighlightWebpackPlugin = class {
  apiKey;
  appVersion;
  path;
  basePath;
  constructor(apiKey, appVersion, path, basePath) {
    this.apiKey = apiKey;
    this.appVersion = appVersion;
    this.path = path;
    this.basePath = basePath;
  }
  apply(compiler) {
    compiler.hooks.afterEmit.tap("HighlightWebpackPlugin", () => {
      uploadSourcemaps({
        apiKey: this.apiKey,
        appVersion: this.appVersion,
        path: this.path,
        basePath: this.basePath,
        allowNoop: true
      });
    });
    return compiler;
  }
};

// src/util/withHighlightConfig.ts
var getDefaultOpts = async (config, highlightOpts) => {
  const isProdBuild = process.env.NODE_ENV === "production";
  const hasSourcemapApiKey = !!process.env.HIGHLIGHT_SOURCEMAP_UPLOAD_API_KEY || !!highlightOpts?.apiKey;
  let version = null;
  if (config.generateBuildId) {
    const buildId = config.generateBuildId();
    if (typeof buildId === "string") {
      version = buildId;
    } else {
      version = await buildId;
    }
  }
  return {
    uploadSourceMaps: isProdBuild && (highlightOpts?.uploadSourceMaps ?? (!config.productionBrowserSourceMaps && hasSourcemapApiKey)),
    configureHighlightProxy: highlightOpts?.configureHighlightProxy ?? true,
    apiKey: highlightOpts?.apiKey ?? "",
    appVersion: highlightOpts?.appVersion ?? version ?? "",
    serviceName: highlightOpts?.serviceName ?? "",
    sourceMapsPath: highlightOpts?.sourceMapsPath ?? ".next/",
    sourceMapsBasePath: highlightOpts?.sourceMapsBasePath ?? "_next/"
  };
};
var getHighlightConfig = async (config, highlightOpts) => {
  const defaultOpts = await getDefaultOpts(config, highlightOpts);
  let newRewrites = config.rewrites;
  if (defaultOpts.uploadSourceMaps || defaultOpts.configureHighlightProxy) {
    newRewrites = async () => {
      let re;
      if (!config.rewrites) {
        re = new Array();
      } else {
        re = await config.rewrites();
      }
      const sourcemapRewrite = {
        source: "/:path*.map",
        destination: "/404"
      };
      const highlightRewrite = {
        source: "/highlight-events",
        destination: "https://pub.highlight.run"
      };
      if (!re || Array.isArray(re)) {
        return {
          beforeFiles: defaultOpts.uploadSourceMaps ? [sourcemapRewrite] : [],
          afterFiles: defaultOpts.configureHighlightProxy ? (re ?? []).concat(highlightRewrite) : [],
          fallback: []
        };
      } else {
        return {
          beforeFiles: defaultOpts.uploadSourceMaps ? (re.beforeFiles ?? []).concat(sourcemapRewrite) : re.beforeFiles,
          afterFiles: defaultOpts.configureHighlightProxy ? (re.afterFiles ?? []).concat(highlightRewrite) : re.afterFiles,
          fallback: re.fallback
        };
      }
    };
  }
  let newWebpack = config.webpack;
  if (defaultOpts.uploadSourceMaps) {
    newWebpack = (webpackConfig, opts) => {
      let originalConfig = webpackConfig;
      if (config.webpack) {
        originalConfig = config.webpack(webpackConfig, opts);
      }
      originalConfig.plugins.push(
        new HighlightWebpackPlugin(
          defaultOpts.apiKey,
          defaultOpts.appVersion,
          defaultOpts.sourceMapsPath,
          defaultOpts.sourceMapsBasePath
        )
      );
      return originalConfig;
    };
  }
  return {
    ...config,
    productionBrowserSourceMaps: defaultOpts.uploadSourceMaps || config.productionBrowserSourceMaps,
    rewrites: newRewrites,
    webpack: newWebpack
  };
};
var withHighlightConfig = async (config, highlightOpts) => {
  if (typeof config === "function") {
    return async (phase, { defaultConfig }) => {
      const userNextConfigObject = config(phase, { defaultConfig });
      if (typeof userNextConfigObject === "function") {
        const nc = await userNextConfigObject;
        return await getHighlightConfig(nc, highlightOpts);
      } else {
        return await getHighlightConfig(
          userNextConfigObject,
          highlightOpts
        );
      }
    };
  } else {
    return await getHighlightConfig(config, highlightOpts);
  }
};

// src/server.ts
import { H as H3 } from "@highlight-run/node";
var Highlight3 = PageRouterHighlight;
function PageRouterHighlight(env) {
  if (process.env.NEXT_RUNTIME === "nodejs") {
    return Highlight(env);
  } else {
    throw new Error(
      `unidentified NEXT_RUNTIME: ${process.env.NEXT_RUNTIME}`
    );
  }
}
function AppRouterHighlight(env) {
  if (process.env.NEXT_RUNTIME === "nodejs") {
    return Highlight2(env);
  } else {
    throw new Error(
      `unidentified NEXT_RUNTIME: ${process.env.NEXT_RUNTIME}`
    );
  }
}
function EdgeHighlight(_) {
  throw new Error(`unsupported NEXT_RUNTIME: ${process.env.NEXT_RUNTIME}`);
}
export {
  AppRouterHighlight,
  EdgeHighlight,
  H3 as H,
  Highlight3 as Highlight,
  PageRouterHighlight,
  registerHighlight,
  withHighlightConfig
};
//# sourceMappingURL=server.js.map